function p = pbm(u, time)
% PBM cdf of the maximum of a Brownian Motion on [0,T]
% 
% Syntax
%    p = pbm(u,t)
%    p = pbm(u)
%
% Description 
% PBM(U,T) computes the cumulative distribution function of the supremum 
% of the Brownian motion in the interval [0,T] at each of the values in U. 
% The input parameter T must be a positive scalar. The values in U must
% be positive. The default value of T is 1. 
%  
% Reference:
% "Probability and Real Analysis" by Dudley, R. (2004). p. 459
% "A toolbox note on the distribution of the maximum of Gaussian process" 
% by Azais, J.M. & Lozada-Chang, L.  

% Li-Vang Lozada-Chang 
% Version 2012/10/07 

if nargin < 2,
    time = 1;
end
ut = u/sqrt(time);
p = 2*ncdf(ut)-1;

    function y = ncdf(x)
        % standard normal cdf
        y = erfc(-x ./ sqrt(2))/2;
    end
end
