function Q = qnou(P, t)
% QNOU inverse CDF of the sup. of abs. val. of the Ornstein-Uhlenbeck process
%
% Syntax
%   q = qnou(p,t)
%   q = qnou(p)
%
% Description
% QOU(P,T) computes the inverse of the cumulative distribution function of
% the supremum of the absolute value of the Normalized Bessel Process in 
% the interval [0,T] at each of the values in P.
% The input parameter T must be a positive scalar. The values in P must
% probability values.
% The default value of parameter T is 1.
%
% Remark
% The computation is possible for 0 < P < 5. 
% P must be equal or greater than 0.25. 
% Depending of your hadware and the length of P this function could take 
% several minutes to compute.
%
% Reference
% 1- "Crossing probabilities for a square root boundary by a Bessel
%     process" by DeLong, David M
%     Commun. Stat., Theory Methods A, 1981.
% 2- "A toolbox note on the distribution of the maximum of Gaussian process"
%    by Azais, J.M. & Lozada-Chang, L.

% Version 2012/10/11
% Li-Vang Lozada-Chang

if nargin < 2,
    t = 1;
end
T = exp(2*t);  %modif 2018
Q = qnbp(P, T, 1);

end